(* Js_of_ocaml compiler
 * http://www.ocsigen.org/js_of_ocaml/
 * Copyright (C) 2019 Hugo Heuzard
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, with linking exception;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *)

module Block : sig
  val make : tag:int -> args:Javascript.element list -> Javascript.expression

  val tag : Javascript.expression -> Javascript.expression

  val field : Javascript.expression -> int -> Javascript.expression
end

module Array : sig
  val make : tag:int -> args:Javascript.element list -> Javascript.expression

  val length : Javascript.expression -> Javascript.expression

  val field : Javascript.expression -> Javascript.expression -> Javascript.expression
end

val is_block : Javascript.expression -> Javascript.expression

val is_immediate : Javascript.expression -> Javascript.expression
